# LitAlign

<div align="center">
  <img width="776" alt="Screenshot 2025-06-09 at 10 24 49 PM" src="https://github.com/user-attachments/assets/07e462cc-d6ef-4c57-8dbf-8292cb69436e" />
</div>

---

## Installation

```bash
pip install litalign
```
